Sorting algorithm
------------------

To use (with caution), simply do::

    >>> import koffisortwork
    >>> print sorting.bubble_sort()
    >>> print sorting.selection_sort()
    >>> print sorting.insertion_sort()
    >>> print sorting.quick_sort()
